@@ -16,8 +16,8 @@
 //! systems where a simple typo could cause an unexpected outage, AppConfig includes
 //! validators. A validator provides a syntactic or semantic check to ensure that the
 //! configuration you want to deploy works as intended. To validate your application
-//! configuration data, you provide a schema or a Lambda function that runs against the
-//! configuration. The configuration deployment or update can only proceed when the
+//! configuration data, you provide a schema or an Amazon Web Services Lambda function that runs against
+//! the configuration. The configuration deployment or update can only proceed when the
 //! configuration data is valid.</p>
 //! <p>During a configuration deployment, AppConfig monitors the application to ensure that the
 //! deployment is successful. If the system encounters an error, AppConfig rolls back the
@@ -29,15 +29,15 @@
 //! <ul>
 //! <li>
 //! <p>
-//! <b>Application tuning</b>: Use AppConfig to carefully
-//! introduce changes to your application that can only be tested with production
-//! traffic.</p>
+//! <b>Feature flags</b>: Use AppConfig to turn on new
+//! features that require a timely deployment, such as a product launch or announcement.
+//! </p>
 //! </li>
 //! <li>
 //! <p>
-//! <b>Feature toggle</b>: Use AppConfig to turn on new
-//! features that require a timely deployment, such as a product launch or announcement.
-//! </p>
+//! <b>Application tuning</b>: Use AppConfig to carefully
+//! introduce changes to your application that can only be tested with production
+//! traffic.</p>
 //! </li>
 //! <li>
 //! <p>
@@ -68,6 +68,7 @@
 // Code generated by software.amazon.smithy.rust.codegen.smithy-rs. DO NOT EDIT.
 pub use error_meta::Error;
 
+#[doc(inline)]
 pub use config::Config;
 
 mod aws_endpoint;
@@ -100,10 +101,12 @@ pub mod output;
 pub mod paginator;
 /// Crate version number.
 pub static PKG_VERSION: &str = env!("CARGO_PKG_VERSION");
-pub use aws_smithy_http::byte_stream::ByteStream;
-pub use aws_smithy_http::result::SdkError;
-pub use aws_smithy_types::Blob;
-pub use aws_smithy_types::DateTime;
+/// Re-exported types from supporting crates.
+pub mod types {
+    pub use aws_smithy_http::result::SdkError;
+    pub use aws_smithy_types::Blob;
+    pub use aws_smithy_types::DateTime;
+}
 static API_METADATA: aws_http::user_agent::ApiMetadata =
     aws_http::user_agent::ApiMetadata::new("appconfig", PKG_VERSION);
 pub use aws_smithy_http::endpoint::Endpoint;
@@ -111,4 +114,5 @@ pub use aws_smithy_types::retry::RetryConfig;
 pub use aws_types::app_name::AppName;
 pub use aws_types::region::Region;
 pub use aws_types::Credentials;
+#[doc(inline)]
 pub use client::Client;
